//
//  AppDelegate.m
//  Phototype is an innovative interface for browsing an image database
//
//  Created by Alexis Taugeron on 21/11/10.
//  Copyright 2010 Alexis Taugeron & Adrien Kohlbecker
//
//	Licensed under the Apache License, Version 2.0 (the "License");
//	you may not use this file except in compliance with the License.
//	You may obtain a copy of the License at
//	
//	http://www.apache.org/licenses/LICENSE-2.0
//	
//	Unless required by applicable law or agreed to in writing, software
//	distributed under the License is distributed on an "AS IS" BASIS,
//	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//	See the License for the specific language governing permissions and
//	limitations under the License.
//

#import "AppDelegate.h"

@implementation AppDelegate

@synthesize window;


#pragma mark -
#pragma mark Application lifecycle

- (BOOL)application:(UIApplication *)application didFinishLaunchingWithOptions:(NSDictionary *)launchOptions {
    
	//Color config
	window.backgroundColor = PHOTOTYPE_GRID_BACKGROUND_COLOR;
	
	UIViewController *rootViewController;
	
	//We create the local source (only one available for this prototype) and the database connected to this source
	source = [[LocalSource alloc] init];
	database = [[ImageDatabase alloc] initWithSource:source];
	
	//We make the split view controller and its master and detail controllers
	filterPanel = [[FilterPanelController alloc] initWithNibName:nil bundle:nil];
	grid = [[ImageGridController alloc] initWithDatabase:database];
	split = [[SplitViewController alloc] initWithFilterPanel:filterPanel grid:grid];
    
	//The constant PHOTOTYPE_USE_NAVIGATION indicates if we should use a navigation controller as root view controller
	if (PHOTOTYPE_USE_NAVIGATION) {
		navigation = [[NavigationController alloc] initWithRootViewController:split];
		rootViewController = navigation;
	} else {
		rootViewController = split;
	}
	
	[window addSubview:rootViewController.view];
    
    [self.window makeKeyAndVisible];
    
    return YES;
}


- (void)applicationWillResignActive:(UIApplication *)application {
    /*
     Sent when the application is about to move from active to inactive state. This can occur for certain types of temporary interruptions (such as an incoming phone call or SMS message) or when the user quits the application and it begins the transition to the background state.
     Use this method to pause ongoing tasks, disable timers, and throttle down OpenGL ES frame rates. Games should use this method to pause the game.
     */
}


- (void)applicationDidBecomeActive:(UIApplication *)application {
    /*
     Restart any tasks that were paused (or not yet started) while the application was inactive.
     */
}


- (void)applicationWillTerminate:(UIApplication *)application {
    /*
     Called when the application is about to terminate.
     */
}


#pragma mark -
#pragma mark Memory management

- (void)applicationDidReceiveMemoryWarning:(UIApplication *)application {
    /*
     Free up as much memory as possible by purging cached data objects that can be recreated (or reloaded from disk) later.
     */
}


- (void)dealloc {
    [window release];
	[navigation release];
	[split release];
	[filterPanel release];
	[grid release];
	[source release];
	[database release];
    [super dealloc];
}


@end
