//
//  Image.h
//  An abstract representation of an image, with the metadata
//
//  Created by Alexis Taugeron on 21/11/10.
//  Copyright 2010 Alexis Taugeron & Adrien Kohlbecker
//
//	Licensed under the Apache License, Version 2.0 (the "License");
//	you may not use this file except in compliance with the License.
//	You may obtain a copy of the License at
//	
//	http://www.apache.org/licenses/LICENSE-2.0
//	
//	Unless required by applicable law or agreed to in writing, software
//	distributed under the License is distributed on an "AS IS" BASIS,
//	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//	See the License for the specific language governing permissions and
//	limitations under the License.
//	

#import <Foundation/Foundation.h>
#import "ImageManager.h"
#import "ImageSource.h"
#import "ImageSourceMetadataDelegate.h"


@interface Image : NSObject <ImageSourceMetadataDelegate> {
	NSString *identifier;
	id <ImageSource> source;
	NSDictionary *metadata;
	BOOL ready;
}

@property (readonly) NSString *identifier;
@property (readonly,getter=isReady) BOOL ready;

//Initialization
- (id)initWithID:(NSString *)identifier source:(id <ImageSource>)source;

//Metadata accessors
- (NSArray *)getMetadataList;
- (id)valueForMetadata:(NSString *)metadataName;
- (void)setValue:(id)value forMetadata:(NSString *)metadataName;

//Visual representations accessors
- (void)requestFullSizeRepresentationForSender:(id <ImageManager>)sender;
- (void)requestThumbnailRepresentationOfSize:(NSUInteger)size sender:(id <ImageManager>)sender;

//Key-value tricks
- (void)checkReady;

//Memory management
- (void)cleanMemory;

@end
