//
//  LocalSource.m
//  This class is specific to this early prototype. It gets the images from the local ressource.
//
//  Created by Alexis Taugeron on 21/11/10.
//  Copyright 2010 Alexis Taugeron & Adrien Kohlbecker
//
//	Licensed under the Apache License, Version 2.0 (the "License");
//	you may not use this file except in compliance with the License.
//	You may obtain a copy of the License at
//	
//	http://www.apache.org/licenses/LICENSE-2.0
//	
//	Unless required by applicable law or agreed to in writing, software
//	distributed under the License is distributed on an "AS IS" BASIS,
//	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//	See the License for the specific language governing permissions and
//	limitations under the License.
//	

#import "LocalSource.h"

NSUInteger const NUMBER_OF_LOCAL_IMAGES = 74;

@implementation LocalSource


#pragma mark -
#pragma mark ImageSource protocol

- (void)requestIdentifiersListForSender:(id <ImageSourceListDelegate>)sender {
	//For this local source (specific to this prototype), the identifiers will be the filenames (01.jpg to 74.jpg for example)
	//Set the number formatter which will transform numbers into identifiers (here 3 becomes @"03.jpg" for example)
	NSNumberFormatter *formatter = [[NSNumberFormatter alloc] init];
	[formatter setFormatWidth:[[NSString stringWithFormat:@"%u",NUMBER_OF_LOCAL_IMAGES] length]];
	[formatter setPaddingCharacter:@"0"];
	
	//Build the array of identifiers
	NSMutableArray *identifiers = [[NSMutableArray alloc] initWithCapacity:NUMBER_OF_LOCAL_IMAGES];
	NSUInteger counter;
	for (counter = 1 ; counter <= NUMBER_OF_LOCAL_IMAGES ; counter++) {
		NSString *number = [formatter stringFromNumber:[NSNumber numberWithUnsignedInt:counter]];
		NSString *identifier = [NSString stringWithFormat:@"%@.jpg",number];
		[identifiers addObject:identifier];
	}
	
	//Send the result
	[sender identifiersListReady:[identifiers autorelease]];
	
	//Release phase
	[formatter release];
}

- (void)requestMetadataForSender:(id <ImageSourceMetadataDelegate>)sender {
	//At this point we don't care about metadata yet, but we'll come to that later :-)
	//We just send an empty dictionary
	[sender metadataReady:[NSDictionary dictionary]];
}

- (void)requestFullSizeRepresentationWithID:(NSString *)identifier forSender:(id <ImageManager>)sender {
	//Get the image from the ressources
	UIImage *image = [UIImage imageNamed:identifier];
	
	//Send the result
	[[NSOperationQueue mainQueue] addOperationWithBlock:^{
		[sender representationReady:image forImage:identifier];
	}];
}

- (void)requestThumbnailRepresentationOfSize:(NSUInteger)size ID:(NSString *)identifier sender:(id <ImageManager>)sender {
	//Create the thumbnail identifier and path
	NSString *thumbnailIdentifier = [NSString stringWithFormat:@"%@-thumbnail",identifier];
	NSString *thumbnailPath = [NSString stringWithFormat:@"%@%@",NSTemporaryDirectory(),thumbnailIdentifier];
	
	//If the thumbnail doesn't exist yet, we create it. Otherwise we retrieve it from the disk.
	UIImage *thumbnail;
	if (![[NSFileManager defaultManager] fileExistsAtPath:thumbnailPath] || PHOTOTYPE_ERASE_CACHE) {
		UIImage *fullsizeRepresentation = [UIImage imageNamed:identifier];
		thumbnail = [fullsizeRepresentation thumbnailImage:size transparentBorder:0 cornerRadius:size/10 interpolationQuality:kCGInterpolationDefault];
		[UIImagePNGRepresentation(thumbnail) writeToFile:thumbnailPath atomically:YES];
		
		//DEBUG LINES
		NSLog(@"Resizing thumbnail for index %@", identifier);
		//-DEBUG LINES
	} else {
		//DEBUG LINES
		NSLog(@"Retrieving thumbnail from cache for index %@", identifier);
		//-DEBUG LINES
		
		thumbnail = [UIImage imageWithContentsOfFile:thumbnailPath];
	}
	
	//Send the result
	[[NSOperationQueue mainQueue] addOperationWithBlock:^{
		[sender representationReady:thumbnail forImage:identifier];
	}];
}

@end
