//
//  SplitViewController.m
//  This is an advanced split view controller based on MGSplitViewController, customized for our needs.
//
//  Created by Alexis Taugeron on 23/11/10.
//  Copyright 2010 Alexis Taugeron & Adrien Kohlbecker
//
//	Licensed under the Apache License, Version 2.0 (the "License");
//	you may not use this file except in compliance with the License.
//	You may obtain a copy of the License at
//	
//	http://www.apache.org/licenses/LICENSE-2.0
//	
//	Unless required by applicable law or agreed to in writing, software
//	distributed under the License is distributed on an "AS IS" BASIS,
//	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//	See the License for the specific language governing permissions and
//	limitations under the License.
//	

#import "SplitViewController.h"

@interface SplitViewController ()

- (void)toggle;

@end


@implementation SplitViewController


#pragma mark -
#pragma mark Initialization

- (id)initWithFilterPanel:(FilterPanelController *)filterPanel grid:(ImageGridController *)grid {
	if ((self = [super initWithNibName:nil bundle:nil])) {
		//Retain the parameters
		self.masterViewController = filterPanel;
		self.detailViewController = grid;
		grid.delegate = self;
		
		//Set up the UI
		self.navigationItem.title = PHOTOTYPE_NAVIGATION_TITLE;
		showsFilterPanel = NO;
		self.vertical = UIInterfaceOrientationIsLandscape(self.interfaceOrientation);
		float splitPosition = UIInterfaceOrientationIsPortrait(self.interfaceOrientation) ? PHOTOTYPE_FILTER_PANEL_PORTRAIT_HEIGHT : PHOTOTYPE_FILTER_PANEL_LANDSCAPE_WIDTH;
		[self setSplitPosition:splitPosition];
		
		//Set up the toggle button (we should make something better in the future, a button is quite ugly :-p)
		UIBarButtonItem *toggle = [[UIBarButtonItem alloc] initWithTitle:PHOTOTYPE_TOGGLE_FILTER_PANEL_TEXT style:PHOTOTYPE_TOGGLE_FILTER_PANEL_STYLE target:self action:@selector(toggle)];
		self.navigationItem.rightBarButtonItem = toggle;
		[toggle release];
	}
	
	return self;
}


#pragma mark -
#pragma mark Rotation

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation {
    return YES;
}

- (void)willRotateToInterfaceOrientation:(UIInterfaceOrientation)toInterfaceOrientation duration:(NSTimeInterval)duration {
	//Update the UI depending on the orientation
	self.showsMasterInPortrait = showsFilterPanel;
	self.showsMasterInLandscape = showsFilterPanel;
	self.splitPosition = UIInterfaceOrientationIsPortrait(toInterfaceOrientation) ? PHOTOTYPE_FILTER_PANEL_PORTRAIT_HEIGHT : PHOTOTYPE_FILTER_PANEL_LANDSCAPE_WIDTH;
	if ((UIInterfaceOrientationIsPortrait(toInterfaceOrientation) && UIInterfaceOrientationIsLandscape(self.interfaceOrientation))
		||
		(UIInterfaceOrientationIsLandscape(toInterfaceOrientation) && UIInterfaceOrientationIsPortrait(self.interfaceOrientation)))
	{
		[self toggleSplitOrientation:self];
	}
	
	[super willRotateToInterfaceOrientation:toInterfaceOrientation duration:duration];
}


#pragma mark -
#pragma mark Actions

- (void)toggle {
	showsFilterPanel = !showsFilterPanel;
	[self.detailViewController setValue:[NSNumber numberWithBool:!showsFilterPanel] forKey:@"fullScreen"];
	[self toggleMasterView:self];
}

@end
